@@ -76,6 +76,7 @@ class ContentType(proto.Enum):
     ORG_POLICY = 4
     ACCESS_POLICY = 5
     OS_INVENTORY = 6
+    RELATIONSHIP = 7
 
 
 class AnalyzeIamPolicyLongrunningMetadata(proto.Message):
@@ -84,7 +85,8 @@ class AnalyzeIamPolicyLongrunningMetadata(proto.Message):
 
     Attributes:
         create_time (google.protobuf.timestamp_pb2.Timestamp):
-            The time the operation was created.
+            Output only. The time the operation was
+            created.
     """
 
     create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
@@ -138,6 +140,23 @@ class ExportAssetsRequest(proto.Message):
         output_config (google.cloud.asset_v1.types.OutputConfig):
             Required. Output configuration indicating
             where the results will be output to.
+        relationship_types (Sequence[str]):
+            A list of relationship types to export, for example:
+            ``INSTANCE_TO_INSTANCEGROUP``. This field should only be
+            specified if content_type=RELATIONSHIP.
+
+            -  If specified: it snapshots specified relationships. It
+               returns an error if any of the [relationship_types]
+               doesn't belong to the supported relationship types of the
+               [asset_types] or if any of the [asset_types] doesn't
+               belong to the source types of the [relationship_types].
+            -  Otherwise: it snapshots the supported relationships for
+               all [asset_types] or returns an error if any of the
+               [asset_types] has no relationship support. An unspecified
+               asset types field means all supported asset_types. See
+               `Introduction to Cloud Asset
+               Inventory <https://cloud.google.com/asset-inventory/docs/overview>`__
+               for all supported asset types and relationship types.
     """
 
     parent = proto.Field(proto.STRING, number=1,)
@@ -145,6 +164,7 @@ class ExportAssetsRequest(proto.Message):
     asset_types = proto.RepeatedField(proto.STRING, number=3,)
     content_type = proto.Field(proto.ENUM, number=4, enum="ContentType",)
     output_config = proto.Field(proto.MESSAGE, number=5, message="OutputConfig",)
+    relationship_types = proto.RepeatedField(proto.STRING, number=6,)
 
 
 class ExportAssetsResponse(proto.Message):
@@ -228,6 +248,23 @@ class ListAssetsRequest(proto.Message):
             ``ListAssetsRequest``. It is a continuation of a prior
             ``ListAssets`` call, and the API should return the next page
             of assets.
+        relationship_types (Sequence[str]):
+            A list of relationship types to output, for example:
+            ``INSTANCE_TO_INSTANCEGROUP``. This field should only be
+            specified if content_type=RELATIONSHIP.
+
+            -  If specified: it snapshots specified relationships. It
+               returns an error if any of the [relationship_types]
+               doesn't belong to the supported relationship types of the
+               [asset_types] or if any of the [asset_types] doesn't
+               belong to the source types of the [relationship_types].
+            -  Otherwise: it snapshots the supported relationships for
+               all [asset_types] or returns an error if any of the
+               [asset_types] has no relationship support. An unspecified
+               asset types field means all supported asset_types. See
+               `Introduction to Cloud Asset
+               Inventory <https://cloud.google.com/asset-inventory/docs/overview>`__
+               for all supported asset types and relationship types.
     """
 
     parent = proto.Field(proto.STRING, number=1,)
@@ -236,6 +273,7 @@ class ListAssetsRequest(proto.Message):
     content_type = proto.Field(proto.ENUM, number=4, enum="ContentType",)
     page_size = proto.Field(proto.INT32, number=5,)
     page_token = proto.Field(proto.STRING, number=6,)
+    relationship_types = proto.RepeatedField(proto.STRING, number=7,)
 
 
 class ListAssetsResponse(proto.Message):
@@ -290,6 +328,23 @@ class BatchGetAssetsHistoryRequest(proto.Message):
             not set, the snapshot of the assets at end_time will be
             returned. The returned results contain all temporal assets
             whose time window overlap with read_time_window.
+        relationship_types (Sequence[str]):
+            Optional. A list of relationship types to output, for
+            example: ``INSTANCE_TO_INSTANCEGROUP``. This field should
+            only be specified if content_type=RELATIONSHIP.
+
+            -  If specified: it outputs specified relationships' history
+               on the [asset_names]. It returns an error if any of the
+               [relationship_types] doesn't belong to the supported
+               relationship types of the [asset_names] or if any of the
+               [asset_names]'s types doesn't belong to the source types
+               of the [relationship_types].
+            -  Otherwise: it outputs the supported relationships'
+               history on the [asset_names] or returns an error if any
+               of the [asset_names]'s types has no relationship support.
+               See `Introduction to Cloud Asset
+               Inventory <https://cloud.google.com/asset-inventory/docs/overview>`__
+               for all supported asset types and relationship types.
     """
 
     parent = proto.Field(proto.STRING, number=1,)
@@ -298,6 +353,7 @@ class BatchGetAssetsHistoryRequest(proto.Message):
     read_time_window = proto.Field(
         proto.MESSAGE, number=4, message=gca_assets.TimeWindow,
     )
+    relationship_types = proto.RepeatedField(proto.STRING, number=5,)
 
 
 class BatchGetAssetsHistoryResponse(proto.Message):
@@ -675,6 +731,25 @@ class Feed(proto.Message):
             See our `user
             guide <https://cloud.google.com/asset-inventory/docs/monitoring-asset-changes-with-condition>`__
             for detailed instructions.
+        relationship_types (Sequence[str]):
+            A list of relationship types to output, for example:
+            ``INSTANCE_TO_INSTANCEGROUP``. This field should only be
+            specified if content_type=RELATIONSHIP.
+
+            -  If specified: it outputs specified relationship updates
+               on the [asset_names] or the [asset_types]. It returns an
+               error if any of the [relationship_types] doesn't belong
+               to the supported relationship types of the [asset_names]
+               or [asset_types], or any of the [asset_names] or the
+               [asset_types] doesn't belong to the source types of the
+               [relationship_types].
+            -  Otherwise: it outputs the supported relationships of the
+               types of [asset_names] and [asset_types] or returns an
+               error if any of the [asset_names] or the [asset_types]
+               has no replationship support. See `Introduction to Cloud
+               Asset
+               Inventory <https://cloud.google.com/asset-inventory/docs/overview>`__
+               for all supported asset types and relationship types.
     """
 
     name = proto.Field(proto.STRING, number=1,)
@@ -685,6 +760,7 @@ class Feed(proto.Message):
         proto.MESSAGE, number=5, message="FeedOutputConfig",
     )
     condition = proto.Field(proto.MESSAGE, number=6, message=expr_pb2.Expr,)
+    relationship_types = proto.RepeatedField(proto.STRING, number=7,)
 
 
 class SearchAllResourcesRequest(proto.Message):
