@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.asset_v1p1beta1.types import asset_service
@@ -75,14 +75,14 @@ class SearchAllResourcesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[asset_service.SearchAllResourcesResponse]:
+    def pages(self) -> Iterator[asset_service.SearchAllResourcesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[assets.StandardResourceMetadata]:
+    def __iter__(self) -> Iterator[assets.StandardResourceMetadata]:
         for page in self.pages:
             yield from page.results
 
@@ -137,14 +137,14 @@ class SearchAllResourcesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[asset_service.SearchAllResourcesResponse]:
+    async def pages(self) -> AsyncIterator[asset_service.SearchAllResourcesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[assets.StandardResourceMetadata]:
+    def __aiter__(self) -> AsyncIterator[assets.StandardResourceMetadata]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.results:
@@ -203,14 +203,14 @@ class SearchAllIamPoliciesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[asset_service.SearchAllIamPoliciesResponse]:
+    def pages(self) -> Iterator[asset_service.SearchAllIamPoliciesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[assets.IamPolicySearchResult]:
+    def __iter__(self) -> Iterator[assets.IamPolicySearchResult]:
         for page in self.pages:
             yield from page.results
 
@@ -265,14 +265,14 @@ class SearchAllIamPoliciesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[asset_service.SearchAllIamPoliciesResponse]:
+    async def pages(self) -> AsyncIterator[asset_service.SearchAllIamPoliciesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[assets.IamPolicySearchResult]:
+    def __aiter__(self) -> AsyncIterator[assets.IamPolicySearchResult]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.results:
